@@ -2,6 +2,7 @@ package deploy
 
 import (
 	"context"
+	"encoding/json"
 	"fmt"
 	"strings"
 	"sync"
@@ -12,16 +13,19 @@ import (
 	"github.com/logrusorgru/aurora"
 	"github.com/morikuni/aec"
 	"github.com/samber/lo"
-	"github.com/superfly/flyctl/api"
-	"github.com/superfly/flyctl/client"
-	"github.com/superfly/flyctl/flaps"
+	fly "github.com/superfly/fly-go"
+	"github.com/superfly/fly-go/flaps"
 	"github.com/superfly/flyctl/gql"
 	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/buildinfo"
 	"github.com/superfly/flyctl/internal/cmdutil"
+	"github.com/superfly/flyctl/internal/flapsutil"
 	"github.com/superfly/flyctl/internal/machine"
+	"github.com/superfly/flyctl/internal/tracing"
 	"github.com/superfly/flyctl/iostreams"
 	"github.com/superfly/flyctl/terminal"
+	"go.opentelemetry.io/otel/attribute"
+	"go.opentelemetry.io/otel/trace"
 )
 
 const (
@@ -38,7 +42,7 @@ type MachineDeployment interface {
 }
 
 type MachineDeploymentArgs struct {
-	AppCompact             *api.AppCompact
+	AppCompact             *fly.AppCompact
 	DeploymentImage        string
 	Strategy               string
 	EnvFromFlags           []string
@@ -51,11 +55,11 @@ type MachineDeploymentArgs struct {
 	WaitTimeout            *time.Duration
 	LeaseTimeout           *time.Duration
 	ReleaseCmdTimeout      *time.Duration
-	Guest                  *api.MachineGuest
+	Guest                  *fly.MachineGuest
 	IncreasedAvailability  bool
 	AllocPublicIP          bool
 	UpdateOnly             bool
-	Files                  []*api.File
+	Files                  []*fly.File
 	ExcludeRegions         map[string]interface{}
 	OnlyRegions            map[string]interface{}
 	ImmediateMaxConcurrent int
@@ -64,17 +68,17 @@ type MachineDeploymentArgs struct {
 }
 
 type machineDeployment struct {
-	apiClient              *api.Client
+	apiClient              *fly.Client
 	gqlClient              graphql.Client
 	flapsClient            *flaps.Client
 	io                     *iostreams.IOStreams
 	colorize               *iostreams.ColorScheme
-	app                    *api.AppCompact
+	app                    *fly.AppCompact
 	appConfig              *appconfig.Config
 	img                    string
 	machineSet             machine.MachineSet
 	releaseCommandMachine  machine.MachineSet
-	volumes                map[string][]api.Volume
+	volumes                map[string][]fly.Volume
 	strategy               string
 	releaseId              string
 	releaseVersion         int
@@ -88,7 +92,7 @@ type machineDeployment struct {
 	leaseDelayBetween      time.Duration
 	releaseCmdTimeout      time.Duration
 	isFirstDeploy          bool
-	machineGuest           *api.MachineGuest
+	machineGuest           *fly.MachineGuest
 	increasedAvailability  bool
 	listenAddressChecked   sync.Map
 	updateOnly             bool
@@ -100,6 +104,9 @@ type machineDeployment struct {
 }
 
 func NewMachineDeployment(ctx context.Context, args MachineDeploymentArgs) (MachineDeployment, error) {
+	ctx, span := tracing.GetTracer().Start(ctx, "new_machines_deployment")
+	defer span.End()
+
 	if !args.RestartOnly && args.DeploymentImage == "" {
 		return nil, fmt.Errorf("BUG: machines deployment created without specifying the image")
 	}
@@ -108,26 +115,33 @@ func NewMachineDeployment(ctx context.Context, args MachineDeploymentArgs) (Mach
 	}
 	appConfig, err := determineAppConfigForMachines(ctx, args.EnvFromFlags, args.PrimaryRegionFlag, args.Strategy, args.MaxUnavailable, args.Files)
 	if err != nil {
+		tracing.RecordError(span, err, "failed to determine app config for machines")
 		return nil, err
 	}
 
 	// TODO: Blend extraInfo into ValidationError and remove this hack
 	if err, extraInfo := appConfig.ValidateGroups(ctx, lo.Keys(args.ProcessGroups)); err != nil {
 		fmt.Fprintf(iostreams.FromContext(ctx).ErrOut, extraInfo)
+		tracing.RecordError(span, err, "failed to validate process groups")
 		return nil, err
 	}
 
 	if args.AppCompact == nil {
 		return nil, fmt.Errorf("BUG: args.AppCompact should be set when calling this method")
 	}
-	flapsClient, err := flaps.New(ctx, args.AppCompact)
+	flapsClient, err := flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{
+		AppCompact: args.AppCompact,
+		AppName:    args.AppCompact.Name,
+	})
 	if err != nil {
+		tracing.RecordError(span, err, "failed to init flaps client")
 		return nil, err
 	}
 
 	if appConfig.Deploy != nil {
 		_, err = shlex.Split(appConfig.Deploy.ReleaseCommand)
 		if err != nil {
+			tracing.RecordError(span, err, "failed to split release command")
 			return nil, err
 		}
 	}
@@ -166,7 +180,7 @@ func NewMachineDeployment(ctx context.Context, args MachineDeploymentArgs) (Mach
 	}
 
 	io := iostreams.FromContext(ctx)
-	apiClient := client.FromContext(ctx).API()
+	apiClient := fly.ClientFromContext(ctx)
 
 	maxUnavailable := DefaultMaxUnavailable
 	if appConfig.Deploy != nil && appConfig.Deploy.MaxUnavailable != nil {
@@ -205,33 +219,43 @@ func NewMachineDeployment(ctx context.Context, args MachineDeploymentArgs) (Mach
 		processGroups:          args.ProcessGroups,
 	}
 	if err := md.setStrategy(); err != nil {
+		tracing.RecordError(span, err, "failed to set strategy")
 		return nil, err
 	}
 	if err := md.setMachinesForDeployment(ctx); err != nil {
+		tracing.RecordError(span, err, "failed to set machines for first deployemt")
 		return nil, err
 	}
 	if err := md.setVolumes(ctx); err != nil {
+		tracing.RecordError(span, err, "failed to set volumes")
 		return nil, err
 	}
 	if err := md.setImg(ctx); err != nil {
+		tracing.RecordError(span, err, "failed to set img")
 		return nil, err
 	}
 	if err := md.setFirstDeploy(ctx); err != nil {
+		tracing.RecordError(span, err, "failed to set first depoyment")
 		return nil, err
 	}
 
 	// Provisioning must come after setVolumes
 	if err := md.provisionFirstDeploy(ctx, args.AllocPublicIP); err != nil {
+		tracing.RecordError(span, err, "failed to provision first depoloy")
 		return nil, err
 	}
 
 	// validations must happen after every else
 	if err := md.validateVolumeConfig(); err != nil {
+		tracing.RecordError(span, err, "failed to validate volume config")
 		return nil, err
 	}
 	if err = md.createReleaseInBackend(ctx); err != nil {
+		tracing.RecordError(span, err, "failed to create release in backend")
 		return nil, err
 	}
+
+	span.SetAttributes(md.ToSpanAttributes()...)
 	return md, nil
 }
 
@@ -245,8 +269,12 @@ func (md *machineDeployment) setFirstDeploy(ctx context.Context) error {
 }
 
 func (md *machineDeployment) setMachinesForDeployment(ctx context.Context) error {
+	ctx, span := tracing.GetTracer().Start(ctx, "set_machines_for_deployment")
+	defer span.End()
+
 	machines, releaseCmdMachine, err := md.flapsClient.ListFlyAppsMachines(ctx)
 	if err != nil {
+		tracing.RecordError(span, err, "failed to list machines")
 		return err
 	}
 
@@ -254,6 +282,7 @@ func (md *machineDeployment) setMachinesForDeployment(ctx context.Context) error
 		terminal.Debug("Found no machines that are part of Fly Apps Platform. Checking for active machines...")
 		activeMachines, err := md.flapsClient.ListActive(ctx)
 		if err != nil {
+			tracing.RecordError(span, err, "failed to list machines")
 			return err
 		}
 		if len(activeMachines) > 0 {
@@ -263,7 +292,7 @@ func (md *machineDeployment) setMachinesForDeployment(ctx context.Context) error
 	}
 
 	if len(md.onlyRegions) > 0 {
-		var onlyRegionMachines []*api.Machine
+		var onlyRegionMachines []*fly.Machine
 		for _, m := range machines {
 			if _, present := md.onlyRegions[m.Region]; present {
 				onlyRegionMachines = append(onlyRegionMachines, m)
@@ -273,7 +302,7 @@ func (md *machineDeployment) setMachinesForDeployment(ctx context.Context) error
 		machines = onlyRegionMachines
 	}
 	if len(md.excludeRegions) > 0 {
-		var excludeRegionMachines []*api.Machine
+		var excludeRegionMachines []*fly.Machine
 		for _, m := range machines {
 			if _, present := md.excludeRegions[m.Region]; !present {
 				excludeRegionMachines = append(excludeRegionMachines, m)
@@ -283,7 +312,7 @@ func (md *machineDeployment) setMachinesForDeployment(ctx context.Context) error
 		machines = excludeRegionMachines
 	}
 	if len(md.processGroups) > 0 {
-		var processGroupMachines []*api.Machine
+		var processGroupMachines []*fly.Machine
 		for _, m := range machines {
 			if _, present := md.processGroups[m.ProcessGroup()]; present {
 				processGroupMachines = append(processGroupMachines, m)
@@ -295,17 +324,17 @@ func (md *machineDeployment) setMachinesForDeployment(ctx context.Context) error
 
 	for _, m := range machines {
 		if m.Config != nil && m.Config.Metadata != nil {
-			m.Config.Metadata[api.MachineConfigMetadataKeyFlyctlVersion] = buildinfo.Version().String()
-			if m.Config.Metadata[api.MachineConfigMetadataKeyFlyProcessGroup] == "" {
-				m.Config.Metadata[api.MachineConfigMetadataKeyFlyProcessGroup] = md.appConfig.DefaultProcessName()
+			m.Config.Metadata[fly.MachineConfigMetadataKeyFlyctlVersion] = buildinfo.Version().String()
+			if m.Config.Metadata[fly.MachineConfigMetadataKeyFlyProcessGroup] == "" {
+				m.Config.Metadata[fly.MachineConfigMetadataKeyFlyProcessGroup] = md.appConfig.DefaultProcessName()
 			}
 		}
 	}
 
 	md.machineSet = machine.NewMachineSet(md.flapsClient, md.io, machines)
-	var releaseCmdSet []*api.Machine
+	var releaseCmdSet []*fly.Machine
 	if releaseCmdMachine != nil {
-		releaseCmdSet = []*api.Machine{releaseCmdMachine}
+		releaseCmdSet = []*fly.Machine{releaseCmdMachine}
 	}
 	md.releaseCommandMachine = machine.NewMachineSet(md.flapsClient, md.io, releaseCmdSet)
 	return nil
@@ -321,17 +350,17 @@ func (md *machineDeployment) setVolumes(ctx context.Context) error {
 		return fmt.Errorf("Error fetching application volumes: %w", err)
 	}
 
-	unattached := lo.Filter(volumes, func(v api.Volume, _ int) bool {
+	unattached := lo.Filter(volumes, func(v fly.Volume, _ int) bool {
 		return v.AttachedAllocation == nil && v.AttachedMachine == nil
 	})
 
-	md.volumes = lo.GroupBy(unattached, func(v api.Volume) string {
+	md.volumes = lo.GroupBy(unattached, func(v fly.Volume) string {
 		return v.Name
 	})
 	return nil
 }
 
-func (md *machineDeployment) popVolumeFor(name, region string) *api.Volume {
+func (md *machineDeployment) popVolumeFor(name, region string) *fly.Volume {
 	volumes := md.volumes[name]
 	for idx, v := range volumes {
 		if region == "" || region == v.Region {
@@ -344,10 +373,10 @@ func (md *machineDeployment) popVolumeFor(name, region string) *api.Volume {
 
 func (md *machineDeployment) validateVolumeConfig() error {
 	machineGroups := lo.GroupBy(
-		lo.Map(md.machineSet.GetMachines(), func(lm machine.LeasableMachine, _ int) *api.Machine {
+		lo.Map(md.machineSet.GetMachines(), func(lm machine.LeasableMachine, _ int) *fly.Machine {
 			return lm.Machine()
 		}),
-		func(m *api.Machine) string {
+		func(m *fly.Machine) string {
 			return m.ProcessGroup()
 		})
 
@@ -397,7 +426,7 @@ func (md *machineDeployment) validateVolumeConfig() error {
 
 			// Compute the volume differences per region
 			for volSrc, regions := range needsVol {
-				currentPerRegion := lo.CountValuesBy(md.volumes[volSrc], func(v api.Volume) string { return v.Region })
+				currentPerRegion := lo.CountValuesBy(md.volumes[volSrc], func(v fly.Volume) string { return v.Region })
 				needsPerRegion := lo.CountValues(regions)
 
 				var missing []string
@@ -479,6 +508,9 @@ func (md *machineDeployment) setStrategy() error {
 }
 
 func (md *machineDeployment) createReleaseInBackend(ctx context.Context) error {
+	ctx, span := tracing.GetTracer().Start(ctx, "create_backend_release")
+	defer span.End()
+
 	_ = `# @genqlient
 	mutation MachinesCreateRelease($input:CreateReleaseInput!) {
 		createRelease(input:$input) {
@@ -498,6 +530,7 @@ func (md *machineDeployment) createReleaseInBackend(ctx context.Context) error {
 	}
 	resp, err := gql.MachinesCreateRelease(ctx, md.gqlClient, input)
 	if err != nil {
+		tracing.RecordError(span, err, "failed to create machine release")
 		return err
 	}
 	md.releaseId = resp.CreateRelease.Release.Id
@@ -506,6 +539,12 @@ func (md *machineDeployment) createReleaseInBackend(ctx context.Context) error {
 }
 
 func (md *machineDeployment) updateReleaseInBackend(ctx context.Context, status string) error {
+	ctx, span := tracing.GetTracer().Start(ctx, "update_release_in_backend", trace.WithAttributes(
+		attribute.String("release_id", md.releaseId),
+		attribute.String("status", status),
+	))
+	defer span.End()
+
 	_ = `# @genqlient
 	mutation MachinesUpdateRelease($input:UpdateReleaseInput!) {
 		updateRelease(input:$input) {
@@ -521,6 +560,7 @@ func (md *machineDeployment) updateReleaseInBackend(ctx context.Context, status
 	}
 	_, err := gql.MachinesUpdateRelease(ctx, md.gqlClient, input)
 	if err != nil {
+		tracing.RecordError(span, err, "failed to update machine release")
 		return err
 	}
 	return nil
@@ -534,7 +574,7 @@ func (md *machineDeployment) logClearLinesAbove(count int) {
 	}
 }
 
-func determineAppConfigForMachines(ctx context.Context, envFromFlags []string, primaryRegion, strategy string, maxUnavailable *float64, files []*api.File) (*appconfig.Config, error) {
+func determineAppConfigForMachines(ctx context.Context, envFromFlags []string, primaryRegion, strategy string, maxUnavailable *float64, files []*fly.File) (*appconfig.Config, error) {
 	appConfig := appconfig.ConfigFromContext(ctx)
 	if appConfig == nil {
 		return nil, fmt.Errorf("BUG: application configuration must come in the context, be sure to pass it before calling NewMachineDeployment")
@@ -590,3 +630,40 @@ func (md *machineDeployment) ProcessNames() (names []string) {
 	}
 	return
 }
+
+func (md *machineDeployment) ToSpanAttributes() []attribute.KeyValue {
+	attrs := []attribute.KeyValue{
+		attribute.String("deployment.app.name", md.app.Name),
+		attribute.String("deployment.image", md.img),
+		attribute.String("deployment.strategy", md.strategy),
+		attribute.Bool("deployment.skip_smoke_checks", md.skipSmokeChecks),
+		attribute.Bool("deployment.skip_health_checks", md.skipHealthChecks),
+		attribute.Bool("deployment.restart_only", md.restartOnly),
+		attribute.Float64("deployment.max_unavailable", md.maxUnavailable),
+		attribute.Float64("deployment.wait_timeout", md.waitTimeout.Seconds()),
+		attribute.Float64("deployment.lease_timeout", md.leaseTimeout.Seconds()),
+		attribute.Float64("deployment.lease_delay_between", md.leaseDelayBetween.Seconds()),
+		attribute.Float64("deployment.release_cmd_timeout", md.releaseCmdTimeout.Seconds()),
+		attribute.Bool("deployment.increased_availability", md.increasedAvailability),
+		attribute.Bool("deployment.update_only", md.updateOnly),
+		attribute.Int("deployment.immediate_max_concurrency", md.immediateMaxConcurrent),
+		attribute.Int("deployment.volume_initial_size", md.volumeInitialSize),
+	}
+
+	b, err := json.Marshal(md.excludeRegions)
+	if err == nil {
+		attrs = append(attrs, attribute.String("deployment.exclude_regions", string(b)))
+	}
+
+	b, err = json.Marshal(md.onlyRegions)
+	if err == nil {
+		attrs = append(attrs, attribute.String("deployment.only_regions", string(b)))
+	}
+
+	b, err = json.Marshal(md.processGroups)
+	if err == nil {
+		attrs = append(attrs, attribute.String("deployment.process_groups", string(b)))
+	}
+
+	return attrs
+}
