@@ -10,12 +10,14 @@ import (
 	"time"
 
 	"github.com/pkg/errors"
+	"go.opentelemetry.io/otel/attribute"
 
-	"github.com/superfly/flyctl/api"
-	"github.com/superfly/flyctl/flaps"
+	fly "github.com/superfly/fly-go"
+	"github.com/superfly/fly-go/flaps"
 	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/ctrlc"
 	"github.com/superfly/flyctl/internal/machine"
+	"github.com/superfly/flyctl/internal/tracing"
 	"github.com/superfly/flyctl/iostreams"
 )
 
@@ -37,7 +39,7 @@ type blueGreen struct {
 	greenMachines       machineUpdateEntries
 	blueMachines        machineUpdateEntries
 	flaps               *flaps.Client
-	apiClient           *api.Client
+	apiClient           *fly.Client
 	io                  *iostreams.IOStreams
 	colorize            *iostreams.ColorScheme
 	clearLinesAbove     func(count int)
@@ -77,6 +79,9 @@ func BlueGreenStrategy(md *machineDeployment, blueMachines []*machineUpdateEntry
 }
 
 func (bg *blueGreen) CreateGreenMachines(ctx context.Context) error {
+	ctx, span := tracing.GetTracer().Start(ctx, "green_machines_create")
+	defer span.End()
+
 	var greenMachines machineUpdateEntries
 
 	for _, mach := range bg.blueMachines {
@@ -85,6 +90,7 @@ func (bg *blueGreen) CreateGreenMachines(ctx context.Context) error {
 
 		newMachineRaw, err := bg.flaps.Launch(ctx, *launchInput)
 		if err != nil {
+			tracing.RecordError(span, err, "failed to launch machine")
 			return err
 		}
 
@@ -147,6 +153,9 @@ func (bg *blueGreen) allMachinesStarted(stateMap map[string]int) bool {
 }
 
 func (bg *blueGreen) WaitForGreenMachinesToBeStarted(ctx context.Context) error {
+	ctx, span := tracing.GetTracer().Start(ctx, "green_machines_start_wait")
+	defer span.End()
+
 	wait := time.NewTicker(bg.timeout)
 	machineIDToState := map[string]int{}
 	render := bg.renderMachineStates(machineIDToState)
@@ -207,7 +216,7 @@ func (bg *blueGreen) changeDetected(a, b map[string]string) bool {
 	return false
 }
 
-func (bg *blueGreen) renderMachineHealthchecks(state map[string]*api.HealthCheckStatus) func() {
+func (bg *blueGreen) renderMachineHealthchecks(state map[string]*fly.HealthCheckStatus) func() {
 	firstRun := true
 
 	previousView := map[string]string{}
@@ -242,7 +251,7 @@ func (bg *blueGreen) renderMachineHealthchecks(state map[string]*api.HealthCheck
 	}
 }
 
-func (bg *blueGreen) allMachinesHealthy(stateMap map[string]*api.HealthCheckStatus) bool {
+func (bg *blueGreen) allMachinesHealthy(stateMap map[string]*fly.HealthCheckStatus) bool {
 	passed := 0
 
 	bg.healthLock.RLock()
@@ -263,8 +272,11 @@ func (bg *blueGreen) allMachinesHealthy(stateMap map[string]*api.HealthCheckStat
 }
 
 func (bg *blueGreen) WaitForGreenMachinesToBeHealthy(ctx context.Context) error {
+	ctx, span := tracing.GetTracer().Start(ctx, "green_machines_health_wait")
+	defer span.End()
+
 	wait := time.NewTicker(bg.timeout)
-	machineIDToHealthStatus := map[string]*api.HealthCheckStatus{}
+	machineIDToHealthStatus := map[string]*fly.HealthCheckStatus{}
 	errChan := make(chan error)
 	render := bg.renderMachineHealthchecks(machineIDToHealthStatus)
 
@@ -280,7 +292,7 @@ func (bg *blueGreen) WaitForGreenMachinesToBeHealthy(ctx context.Context) error
 			continue
 		}
 
-		machineIDToHealthStatus[gm.leasableMachine.FormattedMachineId()] = &api.HealthCheckStatus{}
+		machineIDToHealthStatus[gm.leasableMachine.FormattedMachineId()] = &fly.HealthCheckStatus{}
 	}
 
 	for _, gm := range bg.greenMachines {
@@ -354,6 +366,9 @@ func (bg *blueGreen) WaitForGreenMachinesToBeHealthy(ctx context.Context) error
 }
 
 func (bg *blueGreen) MarkGreenMachinesAsReadyForTraffic(ctx context.Context) error {
+	ctx, span := tracing.GetTracer().Start(ctx, "mark_green_machines_for_traffic")
+	defer span.End()
+
 	for _, gm := range bg.greenMachines.machines() {
 		if bg.aborted.Load() {
 			return ErrAborted
@@ -370,6 +385,9 @@ func (bg *blueGreen) MarkGreenMachinesAsReadyForTraffic(ctx context.Context) err
 }
 
 func (bg *blueGreen) DestroyBlueMachines(ctx context.Context) error {
+	ctx, span := tracing.GetTracer().Start(ctx, "destroy_blue_machines")
+	defer span.End()
+
 	for _, gm := range bg.blueMachines {
 		if bg.aborted.Load() {
 			return ErrAborted
@@ -392,7 +410,7 @@ func (bg *blueGreen) attachCustomTopLevelChecks() {
 			serviceProtocol := service.Protocol
 
 			for _, check := range service.Checks {
-				cc := api.MachineCheck{
+				cc := fly.MachineCheck{
 					Port:              check.Port,
 					Type:              check.Type,
 					Interval:          check.Interval,
@@ -414,7 +432,7 @@ func (bg *blueGreen) attachCustomTopLevelChecks() {
 				}
 
 				if entry.launchInput.Config.Checks == nil {
-					entry.launchInput.Config.Checks = make(map[string]api.MachineCheck)
+					entry.launchInput.Config.Checks = make(map[string]fly.MachineCheck)
 				}
 				entry.launchInput.Config.Checks[fmt.Sprintf("bg_deployments_%s", *check.Type)] = cc
 			}
@@ -423,6 +441,9 @@ func (bg *blueGreen) attachCustomTopLevelChecks() {
 }
 
 func (bg *blueGreen) Deploy(ctx context.Context) error {
+	ctx, span := tracing.GetTracer().Start(ctx, "bluegreen")
+	defer span.End()
+
 	defer bg.ctrlcHook.Done()
 
 	if bg.aborted.Load() {
@@ -431,10 +452,14 @@ func (bg *blueGreen) Deploy(ctx context.Context) error {
 
 	canPerform, err := bg.apiClient.CanPerformBluegreenDeployment(ctx, bg.appConfig.AppName)
 	if err != nil {
+		tracing.RecordError(span, err, "failed to validate deployment")
 		return err
 	}
 
+	span.SetAttributes(attribute.Bool("can_perform", canPerform))
+
 	if !canPerform {
+		tracing.RecordError(span, ErrOrgLimit, "failed to deploy, orglimit")
 		return ErrOrgLimit
 	}
 
@@ -469,6 +494,7 @@ func (bg *blueGreen) Deploy(ctx context.Context) error {
 
 	fmt.Fprintf(bg.io.ErrOut, "\nWaiting for all green machines to start\n")
 	if err := bg.WaitForGreenMachinesToBeStarted(ctx); err != nil {
+		tracing.RecordError(span, err, "failed to wait for start")
 		return errors.Wrap(err, ErrWaitForStartedState.Error())
 	}
 
@@ -478,6 +504,7 @@ func (bg *blueGreen) Deploy(ctx context.Context) error {
 
 	fmt.Fprintf(bg.io.ErrOut, "\nWaiting for all green machines to be healthy\n")
 	if err := bg.WaitForGreenMachinesToBeHealthy(ctx); err != nil {
+		tracing.RecordError(span, err, "failed to wait for health")
 		return errors.Wrap(err, ErrWaitForHealthy.Error())
 	}
 
@@ -487,6 +514,7 @@ func (bg *blueGreen) Deploy(ctx context.Context) error {
 
 	fmt.Fprintf(bg.io.ErrOut, "\nMarking green machines as ready\n")
 	if err := bg.MarkGreenMachinesAsReadyForTraffic(ctx); err != nil {
+		tracing.RecordError(span, err, "failed to mark as ready for traffic")
 		return errors.Wrap(err, ErrMarkReadyForTraffic.Error())
 	}
 
@@ -496,6 +524,7 @@ func (bg *blueGreen) Deploy(ctx context.Context) error {
 
 	fmt.Fprintf(bg.io.ErrOut, "\nDestroying all blue machines\n")
 	if err := bg.DestroyBlueMachines(ctx); err != nil {
+		tracing.RecordError(span, err, "failed to destroy blue machines")
 		return errors.Wrap(err, ErrDestroyBlueMachines.Error())
 	}
 
@@ -504,6 +533,9 @@ func (bg *blueGreen) Deploy(ctx context.Context) error {
 }
 
 func (bg *blueGreen) Rollback(ctx context.Context, err error) error {
+	ctx, span := tracing.GetTracer().Start(ctx, "rollback")
+	defer span.End()
+
 	if strings.Contains(err.Error(), ErrDestroyBlueMachines.Error()) {
 		fmt.Fprintf(bg.io.ErrOut, "\nFailed to destroy blue machines (%s)\n", strings.Join(bg.hangingBlueMachines, ","))
 		fmt.Fprintf(bg.io.ErrOut, "\nYou can destroy them using `fly machines destroy --force <id>`")
@@ -513,6 +545,7 @@ func (bg *blueGreen) Rollback(ctx context.Context, err error) error {
 	for _, mach := range bg.greenMachines.machines() {
 		err := mach.Destroy(ctx, true)
 		if err != nil {
+			tracing.RecordError(span, err, "failed to destroy green machine")
 			return err
 		}
 	}
