@@ -7,7 +7,7 @@ import (
 	"github.com/olekukonko/tablewriter"
 	"github.com/spf13/cobra"
 
-	"github.com/superfly/flyctl/client"
+	fly "github.com/superfly/fly-go"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/command/orgs"
 	"github.com/superfly/flyctl/internal/config"
@@ -34,7 +34,7 @@ func newLog() *cobra.Command {
 }
 
 func runLog(ctx context.Context) (err error) {
-	client := client.FromContext(ctx).API()
+	client := fly.ClientFromContext(ctx)
 	jsonOutput := config.FromContext(ctx).JSONOutput
 	out := iostreams.FromContext(ctx).Out
 
