@@ -15,8 +15,7 @@ import (
 	"github.com/mgutz/ansi"
 	"github.com/samber/lo"
 
-	"github.com/superfly/flyctl/api"
-	"github.com/superfly/flyctl/client"
+	fly "github.com/superfly/fly-go"
 	"github.com/superfly/flyctl/internal/config"
 	"github.com/superfly/flyctl/internal/flag"
 	"github.com/superfly/flyctl/internal/future"
@@ -204,8 +203,8 @@ var errOrgSlugRequired = NonInteractiveError("org slug must be specified when no
 
 // Org returns the Organization the user has passed in via flag or prompts the
 // user for one.
-func Org(ctx context.Context) (*api.Organization, error) {
-	client := client.FromContext(ctx).API()
+func Org(ctx context.Context) (*fly.Organization, error) {
+	client := fly.ClientFromContext(ctx)
 
 	orgs, err := client.GetOrganizations(ctx)
 	if err != nil {
@@ -242,7 +241,7 @@ func Org(ctx context.Context) (*api.Organization, error) {
 	}
 }
 
-func SelectOrg(ctx context.Context, orgs []api.Organization) (org *api.Organization, err error) {
+func SelectOrg(ctx context.Context, orgs []fly.Organization) (org *fly.Organization, err error) {
 	var options []string
 	for _, org := range orgs {
 		personalCallout := ""
@@ -266,12 +265,14 @@ var (
 )
 
 type RegionInfo struct {
-	Regions       []api.Region
-	DefaultRegion *api.Region
+	Regions       []fly.Region
+	DefaultRegion *fly.Region
 }
 
-var regionsOnce sync.Once
-var regionsFuture *future.Future[RegionInfo]
+var (
+	regionsOnce   sync.Once
+	regionsFuture *future.Future[RegionInfo]
+)
 
 // Fetches all Fly regions and app's default region.
 // Only the first call to this function will issue an HTTP request using ctx.
@@ -279,7 +280,7 @@ var regionsFuture *future.Future[RegionInfo]
 func PlatformRegions(ctx context.Context) *future.Future[RegionInfo] {
 	regionsOnce.Do(func() {
 		regionsFuture = future.Spawn(func() (RegionInfo, error) {
-			client := client.FromContext(ctx).API()
+			client := fly.ClientFromContext(ctx)
 			regions, defaultRegion, err := client.PlatformRegions(ctx)
 			regionInfo := RegionInfo{
 				Regions:       regions,
@@ -292,7 +293,7 @@ func PlatformRegions(ctx context.Context) *future.Future[RegionInfo] {
 	return regionsFuture
 }
 
-func sortedRegions(ctx context.Context, excludedRegionCodes []string) ([]api.Region, *api.Region, error) {
+func sortedRegions(ctx context.Context, excludedRegionCodes []string) ([]fly.Region, *fly.Region, error) {
 	regionInfo, err := PlatformRegions(ctx).Get()
 	if err != nil {
 		return nil, nil, err
@@ -302,7 +303,7 @@ func sortedRegions(ctx context.Context, excludedRegionCodes []string) ([]api.Reg
 	defaultRegion := regionInfo.DefaultRegion
 
 	if len(excludedRegionCodes) > 0 {
-		regions = lo.Filter(regions, func(r api.Region, _ int) bool {
+		regions = lo.Filter(regions, func(r fly.Region, _ int) bool {
 			return !lo.Contains(excludedRegionCodes, r.Code)
 		})
 	}
@@ -314,10 +315,10 @@ func sortedRegions(ctx context.Context, excludedRegionCodes []string) ([]api.Reg
 
 // Region returns the region the user has passed in via flag or prompts the
 // user for one.
-func MultiRegion(ctx context.Context, msg string, splitPaid bool, currentRegions []string, excludedRegionCodes []string, flagName string) (*[]api.Region, error) {
+func MultiRegion(ctx context.Context, msg string, splitPaid bool, currentRegions []string, excludedRegionCodes []string, flagName string) (*[]fly.Region, error) {
 	regions, _, err := sortedRegions(ctx, excludedRegionCodes)
-	paidOnly := []api.Region{}
-	availableRegions := []api.Region{}
+	paidOnly := []fly.Region{}
+	availableRegions := []fly.Region{}
 	if err != nil {
 		return nil, err
 	}
@@ -341,7 +342,7 @@ func MultiRegion(ctx context.Context, msg string, splitPaid bool, currentRegions
 	switch {
 	case regionsList != "":
 
-		regions = lo.Filter(regions, func(region api.Region, _ int) bool {
+		regions = lo.Filter(regions, func(region fly.Region, _ int) bool {
 			return lo.ContainsBy(regionCodes, func(regionCode string) bool {
 				return regionCode == region.Code
 			})
@@ -362,10 +363,10 @@ func MultiRegion(ctx context.Context, msg string, splitPaid bool, currentRegions
 
 // Region returns the region the user has passed in via flag or prompts the
 // user for one.
-func Region(ctx context.Context, splitPaid bool, params RegionParams) (*api.Region, error) {
+func Region(ctx context.Context, splitPaid bool, params RegionParams) (*fly.Region, error) {
 	regions, defaultRegion, err := sortedRegions(ctx, params.ExcludedRegionCodes)
-	paidOnly := []api.Region{}
-	availableRegions := []api.Region{}
+	paidOnly := []fly.Region{}
+	availableRegions := []fly.Region{}
 	if err != nil {
 		return nil, err
 	}
@@ -420,9 +421,9 @@ func Region(ctx context.Context, splitPaid bool, params RegionParams) (*api.Regi
 	}
 }
 
-func sortAndCleanRegions(regions []api.Region, excludedRegionCodes []string) []api.Region {
+func sortAndCleanRegions(regions []fly.Region, excludedRegionCodes []string) []fly.Region {
 	if len(excludedRegionCodes) > 0 {
-		regions = lo.Filter(regions, func(r api.Region, _ int) bool {
+		regions = lo.Filter(regions, func(r fly.Region, _ int) bool {
 			return !lo.Contains(excludedRegionCodes, r.Code)
 		})
 	}
@@ -432,12 +433,12 @@ func sortAndCleanRegions(regions []api.Region, excludedRegionCodes []string) []a
 	return regions
 }
 
-func SelectRegion(ctx context.Context, msg string, paid []api.Region, regions []api.Region, defaultCode string) (region *api.Region, err error) {
+func SelectRegion(ctx context.Context, msg string, paid []fly.Region, regions []fly.Region, defaultCode string) (region *fly.Region, err error) {
 	var defaultOption string
 	var options []string
 	if isInteractive(ctx) && len(paid) > 0 {
 		io := iostreams.FromContext(ctx)
-		fmt.Fprintf(io.ErrOut, "Some regions require a Launch plan or higher (%s).\nSee https://fly.io/plans to set up a plan.\n\n", strings.Join(lo.Map(paid, func(r api.Region, _ int) string { return r.Code }), ", "))
+		fmt.Fprintf(io.ErrOut, "Some regions require a Launch plan or higher (%s).\nSee https://fly.io/plans to set up a plan.\n\n", strings.Join(lo.Map(paid, func(r fly.Region, _ int) string { return r.Code }), ", "))
 	}
 
 	for _, r := range regions {
@@ -461,7 +462,7 @@ func SelectRegion(ctx context.Context, msg string, paid []api.Region, regions []
 	return
 }
 
-func MultiSelectRegion(ctx context.Context, msg string, paid []api.Region, regions []api.Region, currentRegions []string) (selectedRegions []api.Region, err error) {
+func MultiSelectRegion(ctx context.Context, msg string, paid []fly.Region, regions []fly.Region, currentRegions []string) (selectedRegions []fly.Region, err error) {
 	var options []string
 
 	var currentIndices []int
@@ -469,7 +470,7 @@ func MultiSelectRegion(ctx context.Context, msg string, paid []api.Region, regio
 
 	if isInteractive(ctx) && len(paid) > 0 {
 		io := iostreams.FromContext(ctx)
-		fmt.Fprintf(io.ErrOut, "Some regions require a Launch plan or higher (%s).\nSee https://fly.io/plans to set up a plan.\n\n", strings.Join(lo.Map(paid, func(r api.Region, _ int) string { return r.Code }), ", "))
+		fmt.Fprintf(io.ErrOut, "Some regions require a Launch plan or higher (%s).\nSee https://fly.io/plans to set up a plan.\n\n", strings.Join(lo.Map(paid, func(r fly.Region, _ int) string { return r.Code }), ", "))
 	}
 
 	for i, r := range regions {
@@ -492,39 +493,7 @@ func MultiSelectRegion(ctx context.Context, msg string, paid []api.Region, regio
 	return
 }
 
-var errVMsizeRequired = NonInteractiveError("vm size must be specified when not running interactively")
-
-func VMSize(ctx context.Context, def string) (size *api.VMSize, err error) {
-	client := client.FromContext(ctx).API()
-
-	vmSizes, err := client.PlatformVMSizes(ctx)
-	if err != nil {
-		return nil, err
-	}
-
-	sort.VMSizesBySize(vmSizes)
-
-	switch {
-	case def != "":
-		for _, vmSize := range vmSizes {
-			if def == vmSize.Name {
-				return &vmSize, nil
-			}
-		}
-		return nil, fmt.Errorf("vm size %s not found", def)
-	default:
-		switch vmSize, err := SelectVMSize(ctx, vmSizes); {
-		case err == nil:
-			return vmSize, nil
-		case IsNonInteractive(err):
-			return nil, errVMsizeRequired
-		default:
-			return nil, err
-		}
-	}
-}
-
-func SelectVMSize(ctx context.Context, vmSizes []api.VMSize) (vmSize *api.VMSize, err error) {
+func SelectVMSize(ctx context.Context, vmSizes []fly.VMSize) (vmSize *fly.VMSize, err error) {
 	options := []string{}
 
 	for _, vmSize := range vmSizes {
